==> sammaadmin-1.00.tar.gz: htdocs/user/postldapadmin/samma/samma_add.php <==
<?php

/*
 * postLDAPadmin
 *
 * Copyright (C) 2006,2007 DesigNET, INC.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/***********************************************************
 * SaMMAɲò
 *
 * $RCSfile: samma_add.php,v $
 * $Revision: 1.3 $
 * $Date: 2010/06/24 07:43:43 $
 **********************************************************/

include_once("../../initial");
include_once("lib/dglibpostldapadmin");
include_once("lib/dglibcommon");
include_once("lib/dglibpage");
include_once("lib/dglibsess");
include_once("lib/dglibldap");
include_once("lib/dglibsamma");

/********************************************************
ƥڡ
*********************************************************/

define("OPERATION", "Ź沽ɲ");

/***********************************************************
 * 饹: ˥塼
 **********************************************************/
Class my_page extends page {

    /***********************************************************
     * ܥǥɽʥС饤ɡ
     **********************************************************/
    function display_body() {
        global $sesskey;
        global $dispusr;
        global $del_list;
        global $add_data;

        /* 桼̾ */
        $user = htmlspecialchars($dispusr);
 
        /* ɥᥤ̾ */
        $domain = "";
        if (isset($add_data["domain"]) === TRUE) {
            $domain = htmlspecialchars($add_data["domain"]);
        }

        /* ѥ */
        $pass_radio_r = "checked";
        $pass_radio_i = "";

        if (isset($add_data["password"]) === TRUE) {
            if ($add_data["password"] == 0) {
                $pass_radio_r = "";
                $pass_radio_i = "checked";
            }
        }

        /* ̥ѥ */
        $indivipass = "";
        if (isset($add_data["indivipass"]) === TRUE) {
            $indivipass = htmlspecialchars($add_data["indivipass"]);
        }

        /* Ź沽롼 */
        $rule_radio_on = "checked";
        $rule_radio_off = "";

        if (isset($add_data["rule"]) === TRUE) {
            if ($add_data["rule"] == 0) {
                $rule_radio_on = "";
                $rule_radio_off = "checked";
            }
        }

        /* ݻ */
        $hidden_del = "";
        if (is_array($del_list) === TRUE) {
            foreach ($del_list as $delval) {
                $hidden_del .=<<<EOD
  <input type="hidden" name="delete[]" value="$delval">
EOD;
            }
        }
  

        print<<<EOD
<form method="POST" action="samma_add.php" name="user_add">

  <table class="table">

    <tbody>
      <tr>
        <td class="key1">桼̾</td>
        <td class="value">
          $user
        </td>
      </tr>
      <tr>
        <td class="key1">ɥᥤ̾/᡼륢ɥ쥹</td>
        <td class="value">
          <input type="text" size="30" name="adddomain" value="$domain" maxlength="256">
        </td>
      </tr>
      <tr>
        <td class="key1">Ź沽ѥ</td>
        <td class="value">
          <input type="radio" name="password" value="1" $pass_radio_r>
          <br>
          <input type="radio" name="password" value="0" $pass_radio_i><input type="text" size="16" name="indivipass" value="$indivipass" maxlength="20">
      </tr>
      <tr>
        <td class="key1">Ź沽롼</td>
        <td class="value">
          <input type="radio" name="rule" value="1" $rule_radio_on>о
          <br>
          <input type="radio" name="rule" value="0" $rule_radio_off>о
        </td>
      </tr>
    </tbody>

  </table>
  <div class="must">ɥᥤ̾Ƭˡ@פĤȡ<br>פΤȤӤޤ<br>᡼륢ɥ쥹ϴפΤȤӤޤ</div>
  <br>
  <input type="submit" name="add" value="" class="add_btn">
  <input type="submit" name="cancel" value="" class="cancel_btn">
  <input type="hidden" name="sk" value="$sesskey">
$hidden_del

</form>

EOD;

    }

};

/***********************************************************
 * 
 **********************************************************/

/* 󥹥󥹺 */
$pg = new my_page();

/* ե롢ִեɹåå */
$ret = user_init();
if ($ret === FALSE) {
    $sys_err = TRUE;
    $pg->display(NULL);
    exit (1);
}

/***********************************************************
 * main
 **********************************************************/
/* 桼̾Ǽ */
$user = $env['loginuser'];
$userdn = $env['user_selfdn'];

/* 桼μ */
$ret = get_userdata ($userdn);
if ($ret === FALSE) {
    result_log(OPERATION . ":NG:" . $err_msg);
    $err_msg = "桼μ˼Ԥޤ";
    $sys_err = TRUE;
    $pg->display(NULL);
    exit (1);
}

$dispusr = $web_conf[$url_data['script']]['displayuser'];
$dispusr = htmlspecialchars($ldapdata[0][$dispusr][0]);

/* ݻͼ */
$del_list = "";
if (isset($_POST["delete"]) === TRUE) {
    $del_list = $_POST["delete"];
}

/* ʬ */
/* ɲ */
if (isset($_POST["add"]) === TRUE) {
    /* ͼ */
    $add_data["domain"] = $_POST["adddomain"];
    $add_data["password"] = $_POST["password"];
    $add_data["rule"] = $_POST["rule"];
    $add_data["indivipass"] = $_POST["indivipass"];

    /* ϥå */
    if (check_rcptadd_data($add_data) === FALSE) {
        result_log(OPERATION . ":NG:" . $err_msg);
    } else {
        /* 桼ǤΥХ̵ */
        $env['user_self'] = FALSE;

        /* LDAPϿ */
        $ret = add_rcpt_data($add_data);
        /* ˤǡϿ̾泌顼 */
        if ($ret === FAIL_EXIST) {
            result_log(OPERATION . ":NG:" . $err_msg);
            /* 顼åѹ */
            $err_msg = "ɲä˼Ԥޤ(" .  $add_data["domain"] . ")";
        /* ϿԤϥƥ२顼 */
        } elseif ($ret !== SUCCESS) {
            result_log(OPERATION . ":NG:" . $err_msg);
            /* 顼åѹ */
            $err_msg = "ɲä˼Ԥޤ(" .  $add_data["domain"] . ")";
            $sys_err = TRUE;
            $pg->display(NULL);
            exit (1);
        /*  */
        } else {
            $err_msg = "ɲäޤ(" . $add_data["domain"] . ")";
            result_log(OPERATION . ":OK:" . $err_msg);

            /* ̤ */
            dgp_location("index.php", $err_msg);
            exit (0);
        }
    }
/* 󥻥 */
} elseif (isset($_POST["cancel"]) === TRUE) {
    /* ɲò̤ */
    page_location("index.php", $del_list);
    exit (0);

}


/***********************************************************
 * ɽ
 **********************************************************/

/* ڡν */
$pg->display(CONTENT);

?>

==> sammaadmin-2.00.tar.gz: htdocs/user/postldapadmin/samma/samma_add.php <==
<?php

/*
 * postLDAPadmin
 *
 * Copyright (C) 2006,2007 DesigNET, INC.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/***********************************************************
 * SaMMAɲò
 *
 * $RCSfile: samma_add.php,v $
 * $Revision: 1.4 $
 * $Date: 2013/08/22 02:02:18 $
 **********************************************************/

include_once("../../initial");
include_once("lib/dglibpostldapadmin");
include_once("lib/dglibcommon");
include_once("lib/dglibpage");
include_once("lib/dglibsess");
include_once("lib/dglibldap");
include_once("lib/dglibsamma");

/********************************************************
ƥڡ
*********************************************************/

define("OPERATION", "Ź沽ɲ");
define("TMPLFILE", "samma/samma_user_add.tmpl");

/***********************************************************
 * ؿ
 **********************************************************/
/***********************************************************
 * set_tag_data()
 *
 * ֤ξ򥻥åȤ
 *
 * []
 *      $tag  ֤
 *
 * [֤]
 *       ʤ
 **********************************************************/
function set_tag_data(&$tag) {
    global $sesskey;
    global $dispusr;
    global $del_list;
    global $add_data;

    /* 桼̾ */
    $user = htmlspecialchars($dispusr);
    $tag["<<USER>>"] = $user;

    /* ɥᥤ̾ */
    $domain = "";
    if (isset($add_data["domain"]) === TRUE) {
        $domain = htmlspecialchars($add_data["domain"]);
    }
    $tag["<<DOMAIN>>"] = $domain;

    /* ѥ */
    $pass_radio_r = "checked";
    $pass_radio_i = "";

    if (isset($add_data["password"]) === TRUE) {
        if ($add_data["password"] == 0) {
            $pass_radio_r = "";
            $pass_radio_i = "checked";
        }
    }
    $tag["<<PASS_RADIO_R>>"] = $pass_radio_r;
    $tag["<<PASS_RADIO_I>>"] = $pass_radio_i;

    /* ̥ѥ */
    $indivipass = "";
    if (isset($add_data["indivipass"]) === TRUE) {
        $indivipass = htmlspecialchars($add_data["indivipass"]);
    }
    $tag["<<INDIVIPASS>>"] = $indivipass;

    /* Ź沽롼 */
    $rule_radio_on = "checked";
    $rule_radio_off = "";

    if (isset($add_data["rule"]) === TRUE) {
        if ($add_data["rule"] == 0) {
            $rule_radio_on = "";
            $rule_radio_off = "checked";
        }
    }
    $tag["<<RULE_RADIO_ON>>"] = $rule_radio_on;
    $tag["<<RULE_RADIO_OFF>>"] = $rule_radio_off;

    return TRUE;
}


/***********************************************************
 * 
 **********************************************************/
$tag = array();

/* å󥭡ѿ */
if (isset ($_POST["sk"]) === TRUE) {
    $sesskey = $_POST["sk"];
}

/* ե롢ִեɹåå */
$ret = user_init();
if ($ret === FALSE) {
    $sys_err = TRUE;
    syserr_display();
    exit (1);
}

/***********************************************************
 * main
 **********************************************************/
/* 桼̾Ǽ */
$user = $env['loginuser'];
$userdn = $env['user_selfdn'];

/* 桼μ */
$ret = get_userdata ($userdn);
if ($ret === FALSE) {
    result_log(OPERATION . ":NG:" . $err_msg);
    $err_msg = "桼μ˼Ԥޤ";
    $sys_err = TRUE;
    $pg->display(NULL);
    exit (1);
}

$dispusr = $web_conf[$url_data['script']]['displayuser'];
$dispusr = htmlspecialchars($ldapdata[0][$dispusr][0]);

/* ݻͼ */
$del_list = "";
if (isset($_POST["delete"]) === TRUE) {
    $del_list = $_POST["delete"];
}

/* ʬ */
/* ɲ */
if (isset($_POST["add"]) === TRUE) {
    /* ͼ */
    $add_data["domain"] = $_POST["adddomain"];
    $add_data["password"] = $_POST["password"];
    $add_data["rule"] = $_POST["rule"];
    $add_data["indivipass"] = $_POST["indivipass"];

    /* ϥå */
    if (check_rcptadd_data($add_data) === FALSE) {
        result_log(OPERATION . ":NG:" . $err_msg);
    } else {
        /* 桼ǤΥХ̵ */
        $env['user_self'] = FALSE;

        /* LDAPϿ */
        $ret = add_rcpt_data($add_data);
        /* ˤǡϿ̾泌顼 */
        if ($ret === FAIL_EXIST) {
            result_log(OPERATION . ":NG:" . $err_msg);
            /* 顼åѹ */
            $err_msg = "ɲä˼Ԥޤ(" .  $add_data["domain"] . ")";
        /* ϿԤϥƥ२顼 */
        } elseif ($ret !== SUCCESS) {
            result_log(OPERATION . ":NG:" . $err_msg);
            /* 顼åѹ */
            $err_msg = "ɲä˼Ԥޤ(" .  $add_data["domain"] . ")";
            $sys_err = TRUE;
            syserr_display();
            exit (1);
        /*  */
        } else {
            $err_msg = "ɲäޤ(" . $add_data["domain"] . ")";
            result_log(OPERATION . ":OK:" . $err_msg);

            /* ̤ */
            dgp_location("index.php", $err_msg);
            exit (0);
        }
    }
/* 󥻥 */
} elseif (isset($_POST["cancel"]) === TRUE) {
    /* ɲò̤ */
    dgp_location("index.php", $del_list);
    exit (0);

}


/***********************************************************
 * ɽ
 **********************************************************/
/* ̤Υ */
set_tag_common($tag);

/* bodyɽ */
set_tag_data($tag);

/* ڡν */
$ret = display(TMPLFILE, $tag, array(), "", "");
if ($ret === FALSE) {
    result_log($log_msg, LOG_ERR);
    syserr_display();
    exit(1);
}

?>
